/*
 The software in this package is distributed under the GNU General
 Public License version 2 (with a special exception described below).

 A copy of GNU General Public License (GPL) is included in this distribution,
 in the file COPYING.GPL.

 As a special exception, if other files instantiate templates or use macros
 or inline functions from this file, or you compile this file and link it
 with other works to produce a work based on this file, this file
 does not by itself cause the resulting work to be covered
 by the GNU General Public License.

 However the source code for this file must still be made available
 in accordance with section (3) of the GNU General Public License.

 This exception does not invalidate any other reasons why a work based
 on this file might be covered by the GNU General Public License.
 */

#ifndef HOST_CONFIGURATION_OPTION_H
#define HOST_CONFIGURATION_OPTION_H

#include <stddef.h>

#include <vector>

#include <boost/program_options.hpp>

#include "config/option/configurationoption.h"

//-----------------------------------------------------------------------------
// HostConfigurationOption
//-----------------------------------------------------------------------------

/**
 * @brief This class represents the "host" section configuration option.
 */
class HostConfigurationOption : public ConfigurationOption
{
public:

    HostConfigurationOption(
            const char *command_string,
            const char *command_description
    );
    HostConfigurationOption(
            const char *command_string,
            const boost::program_options::value_semantic *semantic,
            const char *command_description
    );
    virtual ~HostConfigurationOption();

    std::size_t get_hosts_count() const;
    void set_hosts_count( const std::size_t hosts_count );

private:
    std::size_t HostsCount;

};

//-----------------------------------------------------------------------------
// HostConfigurationOptionItem
//-----------------------------------------------------------------------------

typedef boost::shared_ptr< HostConfigurationOption > HostConfigurationOptionItem;

//-----------------------------------------------------------------------------
// HostConfigurationOptionList
//-----------------------------------------------------------------------------

typedef std::vector< HostConfigurationOptionItem > HostConfigurationOptionList;

#endif // HOST_CONFIGURATION_OPTION_H
